@extends('backend.layout')

{{-- this style will be applied when the direction of language is right-to-left --}}
@includeIf('backend.partials.rtl-style')

@section('content')
    <div class="page-header">
        <h4 class="page-title">{{ __('Equipment Section') }}</h4>
        <ul class="breadcrumbs">
            <li class="nav-home">
                <a href="{{ route('admin.dashboard') }}">
                    <i class="flaticon-home"></i>
                </a>
            </li>
            <li class="separator">
                <i class="flaticon-right-arrow"></i>
            </li>
            <li class="nav-item">
                <a href="#">{{ __('Home Page') }}</a>
            </li>
            <li class="separator">
                <i class="flaticon-right-arrow"></i>
            </li>
            <li class="nav-item">
                <a href="#">{{ __('Equipment Section') }}</a>
            </li>
        </ul>
    </div>
    
    
    @php 
        $new_themes = [3,4,5,6];
    @endphp

    <div class="row">
        <div class="col-md-{{in_array($settings->theme_version, $new_themes) ? '6': '12' }}">
            <div class="card">
                <div class="card-header">
                    <div class="row">
                        <div class="col-lg-{{in_array($settings->theme_version, $new_themes) ? '8': '10' }}">
                            <div class="card-title">{{ __('Update Equipment Section') }}</div>
                        </div>

                        <div class="col-lg-{{in_array($settings->theme_version, $new_themes) ? '4': '2' }}">
                            @includeIf('backend.partials.languages')
                        </div>
                    </div>
                </div>

                <div class="card-body">
                    <div class="row">
                        <div class="col-lg-{{in_array($settings->theme_version, $new_themes) ? '12': '6 offset-lg-3' }}">
                            <form id="equipmentForm"
                                action="{{ route('admin.home_page.update_equipment_section', ['language' => request()->input('language')]) }}"
                                method="POST">
                                @csrf
                                <div class="row">
                                    <div class="col">
                                        <div class="form-group">
                                            <label for="">{{ __('Subtitle') }}</label>
                                            <input type="text" class="form-control" name="subtitle"
                                                value="{{ empty($data->subtitle) ? '' : $data->subtitle }}"
                                                placeholder="{{ __('Enter Subtitle') }}">
                                        </div>
                                    </div>
                                </div>

                                <div class="row">
                                    <div class="col">
                                        <div class="form-group">
                                            <label for="">{{ __('Title') }}</label>
                                            <input type="text" class="form-control" name="title"
                                                value="{{ empty($data->title) ? '' : $data->title }}"
                                                placeholder="{{ __('Enter Title') }}">
                                        </div>
                                    </div>
                                </div>
                                @if ($settings->theme_version == 1 || $settings->theme_version == 2)
                                    <div class="row">
                                        <div class="col">
                                            <div class="form-group">
                                                <label for="">{{ __('Text') }}</label>
                                                <textarea class="form-control" name="text" rows="5" placeholder="{{ __('Enter Text') }}">{{ empty($data->text) ? '' : $data->text }}</textarea>
                                            </div>
                                        </div>
                                    </div>
                                @endif
                            </form>
                        </div>
                    </div>
                </div>

                <div class="card-footer">
                    <div class="row">
                        <div class="col-12 text-center">
                            <button type="submit" form="equipmentForm" class="btn btn-success">
                                {{ __('Update') }}
                            </button>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        @if(in_array($settings->theme_version, $new_themes))
        <div class="col-md-6">
            <div class="card">
                <div class="card-header">
                    <div class="row">
                        <div class="col-lg-{{in_array($settings->theme_version, $new_themes) ? '8': '10' }}">
                            <div class="card-title">{{ __('Featured Equipment Section') }}</div>
                        </div>

                        <div class="col-lg-{{in_array($settings->theme_version, $new_themes) ? '4': '2' }}">
                            @includeIf('backend.partials.languages')
                        </div>
                    </div>
                </div>
                <div class="card-body">
                    <div class="row">
                        <div class="col-lg-{{in_array($settings->theme_version, $new_themes) ? '12': '6 offset-lg-3' }}">
                            <form id="featuredequipmentForm"
                                action="{{ route('admin.home_page.update_featured_equipment_section', ['language' => request()->input('language')]) }}"
                                method="POST">
                                @csrf
                                <div class="row">
                                    <div class="col">
                                        <div class="form-group">
                                            <label for="">{{ __('Featured Section Subtitle') }}</label>
                                            <input type="text" class="form-control" name="featured_section_subtitle"
                                                value="{{ empty($data->featured_section_subtitle) ? '' : $data->featured_section_subtitle }}"
                                                placeholder="{{ __('Enter Subtitle') }}">
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col">
                                        <div class="form-group">
                                            <label for="">{{ __('Featured Section Title') }}</label>
                                            <input type="text" class="form-control" name="featured_section_title"
                                                value="{{ empty($data->featured_section_title) ? '' : $data->featured_section_title }}"
                                                placeholder="{{ __('Enter Title') }}">
                                        </div>
                                    </div>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>

                <div class="card-footer">
                    <div class="row">
                        <div class="col-12 text-center">
                            <button type="submit" form="featuredequipmentForm" class="btn btn-success">
                                {{ __('Update') }}
                            </button>
                        </div>
                    </div>
                </div>

            </div>
        </div>
        @endif
    </div>
@endsection
