@extends('backend.layout')

{{-- this style will be applied when the direction of language is right-to-left --}}
@includeIf('backend.partials.rtl-style')

@section('content')
    <div class="page-header">
        <h4 class="page-title">{{ __('Categories') }}</h4>
        <ul class="breadcrumbs">
            <li class="nav-home">
                <a href="{{ route('admin.dashboard') }}">
                    <i class="flaticon-home"></i>
                </a>
            </li>
            <li class="separator">
                <i class="flaticon-right-arrow"></i>
            </li>
            <li class="nav-item">
                <a href="#">{{ __('Equipment') }}</a>
            </li>
            <li class="separator">
                <i class="flaticon-right-arrow"></i>
            </li>
            <li class="nav-item">
                <a href="#">{{ __('Categories') }}</a>
            </li>
        </ul>
    </div>

    <div class="row">
        @if ($settings->theme_version == 6)
            <div class="col-md-5">
                <div class="card">
                    <div class="card-header">
                        <div class="row">
                            <div class="col-lg-6">
                                <div class="card-title d-inline-block">{{ __('Equipment Category Section') }}</div>
                            </div>

                            <div class="col-lg-5  offset-lg-1">
                                @includeIf('backend.partials.languages')
                            </div>
                        </div>
                    </div>

                    <div class="card-body">
                        <div class="row">
                            <div class="col-lg-12">
                                <form id="secInfo"
                                    action="{{ route('admin.update_eq_category_section', ['language' => request()->input('language')]) }}"
                                    method="POST">
                                    @csrf
                                    <div class="row">
                                        <div class="col">
                                            <div class="form-group">
                                                <label for="">{{ __('Subtitle') }}</label>
                                                <input type="text" class="form-control" name="subtitle"
                                                    value="{{ empty($category_section->subtitle) ? '' : $category_section->subtitle }}"
                                                    placeholder="{{ __('Enter Subtitle') }}">
                                            </div>
                                        </div>
                                    </div>
                                    <div class="row">
                                        <div class="col">
                                            <div class="form-group">
                                                <label for="">{{ __('Title') }}</label>
                                                <input type="text" class="form-control" name="title"
                                                    value="{{ empty($category_section->title) ? '' : $category_section->title }}"
                                                    placeholder="{{ __('Enter Title') }}">
                                            </div>
                                        </div>
                                    </div>
                                </form>
                            </div>
                        </div>
                    </div>
                    <div class="card-footer">
                        <div class="row">
                            <div class="col-12 text-center">
                                <button type="submit" form="secInfo" class="btn btn-success">
                                    {{ __('Update') }}
                                </button>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        @endif
        <div class="col-md-{{ $settings->theme_version == 6 ? '7' : '12' }}">
            <div class="card">
                <div class="card-header">
                    <div class="row">
                        <div class="col-lg-4">
                            <div class="card-title d-inline-block">{{ __('Equipment Categories') }}</div>
                        </div>

                        <div class="col-lg-4">
                            @includeIf('backend.partials.languages')
                        </div>

                        <div class="col-lg-4  mt-2 mt-lg-0">
                            <a href="#" data-toggle="modal" data-target="#createModal"
                                class="btn btn-primary btn-sm float-lg-right float-left"><i class="fas fa-plus"></i>
                                {{ __('Add') }}</a>

                            <button class="btn btn-danger btn-sm float-right mr-2 d-none bulk-delete"
                                data-href="{{ route('admin.equipment_management.bulk_delete_category') }}">
                                <i class="flaticon-interface-5"></i> {{ __('Delete') }}
                            </button>
                        </div>
                    </div>
                </div>

                <div class="card-body">
                    <div class="row">
                        <div class="col-lg-12">
                            @if (count($categories) == 0)
                                <h3 class="text-center mt-2">{{ __('NO EQUIPMENT CATEGORY FOUND') . '!' }}</h3>
                            @else
                                <div class="table-responsive">
                                    <table class="table table-striped mt-3" id="basic-datatables">
                                        <thead>
                                            <tr>
                                                <th scope="col">
                                                    <input type="checkbox" class="bulk-check" data-val="all">
                                                </th>
                                                @if ($settings->theme_version == 6)
                                                    <th scope="col">{{ __('Image') }}</th>
                                                @endif
                                                <th scope="col">{{ __('Name') }}</th>
                                                <th scope="col">{{ __('Status') }}</th>
                                                <th scope="col">{{ __('Featured') }}</th>
                                                <th scope="col">{{ __('Serial Number') }}</th>
                                                <th scope="col">{{ __('Actions') }}</th>
                                            </tr>
                                        </thead>
                                        <tbody>
                                            @foreach ($categories as $category)
                                                <tr>
                                                    <td>
                                                        <input type="checkbox" class="bulk-check"
                                                            data-val="{{ $category->id }}">
                                                    </td>
                                                    @if ($settings->theme_version == 6)
                                                        <td>
                                                            <img @if (!empty($category->image)) src="{{ asset('assets/img/equipments/category-images/' . $category->image) }}"  @else src="{{ asset('assets/img/noimage.jpg') }}" @endif
                                                                alt="equipment category image" width="40">
                                                        </td>
                                                    @endif
                                                    <td>
                                                        {{ strlen($category->name) > 50 ? mb_substr($category->name, 0, 50, 'UTF-8') . '...' : $category->name }}
                                                    </td>
                                                    <td>
                                                        @if ($category->status == 1)
                                                            <h2 class="d-inline-block"><span
                                                                    class="badge badge-success">{{ __('Active') }}</span>
                                                            </h2>
                                                        @else
                                                            <h2 class="d-inline-block"><span
                                                                    class="badge badge-danger">{{ __('Deactive') }}</span>
                                                            </h2>
                                                        @endif
                                                    </td>
                                                    <td>
                                                        <form id="featuredForm-{{ $category->id }}" class="d-inline-block"
                                                          action="{{ route('admin.equipment_management.update_category_featured', ['id' => $category->id]) }}"
                                                          method="post">
                                                          @csrf
                                                          <select
                                                            class="form-control form-control-sm {{ $category->is_featured == 'yes' ? 'bg-success' : 'bg-danger' }}"
                                                            name="is_featured"
                                                            onchange="document.getElementById('featuredForm-{{ $category->id }}').submit()">
                                                            <option value="yes" {{ $category->is_featured == 'yes' ? 'selected' : '' }}>
                                                              {{ __('Yes') }}
                                                            </option>
                                                            <option value="no" {{ $category->is_featured == 'no' ? 'selected' : '' }}>
                                                              {{ __('No') }}
                                                            </option>
                                                          </select>
                                                        </form>
                                                      </td>
                                                    <td>{{ $category->serial_number }}</td>
                                                    <td>
                                                        <a class="btn btn-secondary btn-sm mr-1 editBtn" href="#"
                                                            data-toggle="modal" data-target="#editModal"
                                                            data-id="{{ $category->id }}"
                                                            data-image="{{ $category->image ? asset('assets/img/equipments/category-images/' . $category->image) : asset('assets/img/noimage.jpg') }}"
                                                            data-name="{{ $category->name }}"
                                                            data-status="{{ $category->status }}"
                                                            data-serial_number="{{ $category->serial_number }}">
                                                            <span class="btn-label">
                                                                <i class="fas fa-edit"></i>
                                                            </span>
                                                            {{ __('Edit') }}
                                                        </a>

                                                        <form class="deleteForm d-inline-block"
                                                            action="{{ route('admin.equipment_management.delete_category', ['id' => $category->id]) }}"
                                                            method="post">
                                                            @csrf
                                                            <button type="submit"
                                                                class="btn btn-danger btn-sm deleteBtn">
                                                                <span class="btn-label">
                                                                    <i class="fas fa-trash"></i>
                                                                </span>
                                                                {{ __('Delete') }}
                                                            </button>
                                                        </form>

                                                    </td>
                                                </tr>
                                            @endforeach
                                        </tbody>
                                    </table>
                                </div>
                            @endif
                        </div>
                    </div>
                </div>
                <div class="card-footer"></div>
            </div>
        </div>
    </div>

    {{-- create modal --}}
    @include('backend.instrument.category.create')

    {{-- edit modal --}}
    @include('backend.instrument.category.edit')
@endsection
