@extends('frontend.layout')

@section('pageHeading')
    {{ __('Home') }}
@endsection
@section('metaKeywords')
    @if (!empty($seoInfo))
        {{ $seoInfo->meta_keyword_home }}
    @endif
@endsection

@section('metaDescription')
    @if (!empty($seoInfo))
        {{ $seoInfo->meta_description_home }}
    @endif
@endsection

@section('content')
    @php
        $position = $currencyInfo->base_currency_symbol_position;
        $symbol = $currencyInfo->base_currency_symbol;
    @endphp

    <!-- Home-area start-->
    <section class="hero-banner hero-banner_v5 bg-img bg-cover"
        data-bg-img="{{ asset('assets/img/hero/' . $heroSectionImage) }}" data-aos="fade-up">
        <div class="overlay opacity-80"></div>
        @if (count($sliderInfos) > 0)
            <div class="container container-lg-fluid px-lg-0">
                <div class="row align-items-center gx-xl-5">
                    <div class="col-lg-7">
                        <div class="fluid-left">
                            <div class="swiper home-slider" id="home-slider-4">
                                <div class="swiper-wrapper">
                                    @foreach ($sliderInfos as $sliderInfo)
                                        <div class="swiper-slide">
                                            <div class="banner-content">
                                                <span class="subtitle subtitle_v3 color-light"><span
                                                        class="line"></span>{{ !empty($sliderInfo->text) ? $sliderInfo->text : '' }}</span>
                                                <h1 class="title mb-20 color-white">
                                                    {{ !empty($sliderInfo->title) ? $sliderInfo->title : '' }}</h1>
                                            </div>
                                        </div>
                                    @endforeach
                                </div>
                            </div>
                            <div class="banner-filter-form mt-40 mb-40" data-aos="fade-up">
                                <div class="form-wrapper p-20">
                                    <form action="{{ route('all_equipment') }}" method="GET">
                                        <div class="grid">
                                            <div class="item">
                                                <div class="form-group">
                                                    <div class="form-block">
                                                        <div class="icon color-primary"><i class="far fa-search"></i></div>
                                                        <input class="form-control" type="text" name="keyword"
                                                            placeholder="{{ __('Search title') }}">
                                                    </div>
                                                </div>
                                            </div>
                                            <div class="item">
                                                <div class="form-group">
                                                    <div class="form-block">
                                                        <div class="icon color-primary"><i class="far fa-th-large"></i>
                                                        </div>
                                                        <select class="niceselect" id="category" name="category">
                                                            <option selected value="">{{ __('Categories') }}
                                                            </option>
                                                            @foreach ($equipCategories as $category)
                                                                <option value="{{ $category->slug }}">{{ $category->name }}
                                                                </option>
                                                            @endforeach
                                                        </select>
                                                    </div>
                                                </div>
                                            </div>
                                            <div class="item">
                                                <div class="form-group">
                                                    <div class="form-block">
                                                        <div class="icon color-primary"><i class="fal fa-calendar-alt"></i>
                                                        </div>
                                                        <input type="text" class="form-control" name="date"
                                                            placeholder="{{ __('Search By Date') }}" />
                                                    </div>
                                                </div>
                                            </div>
                                            <div class="item">
                                                <button class="btn btn-md btn-primary w-100" type="submit"
                                                    aria-label="button">{{ __('Search') }}</button>
                                            </div>
                                        </div>
                                    </form>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-5">
                        <div class="right-content mb-40">
                            <div class="swiper home-img-slider" id="home-img-slider-4">
                                <div class="swiper-wrapper">
                                    @foreach ($sliderInfos as $sliderInfo)
                                        <div class="swiper-slide">
                                            <img class="lazyload" src="assets/images/placeholder.png"
                                                data-src="{{ asset('assets/img/hero/sliders/' . $sliderInfo->background_image) }}"
                                                alt="Image">
                                        </div>
                                    @endforeach
                                </div>
                            </div>
                            <div class="overlap"></div>
                        </div>
                    </div>
                </div>
            </div>
        @endif
        <div class="swiper-pagination pagination-fraction position-static" id="home-slider-4-pagination"></div>
    </section>
    <!-- Home-area end -->

    <!-- Works-area start -->
    @if ($secInfo->work_process_section_status == 1)
        <section class="works-area works-area_v5 pt-100 pb-70">
            <div class="container">
                <div class="section-title title-center mb-50">
                    <span class="subtitle subtitle_v3">
                        <span class="line"></span>
                        {{ !empty($workProcessSecInfo->subtitle) ? $workProcessSecInfo->subtitle : '' }}
                        <span class="line"></span>
                    </span>
                    <h2 class="title mt-0">{{ !empty($workProcessSecInfo->title) ? $workProcessSecInfo->title : '' }}</h2>
                </div>
                <div class="row">
                    @if (count($processes) == 0)
                        <h3>{{ __('No Work Process Found') . '!' }}</h3>
                    @else
                        @foreach ($processes as $process)
                            <div class="col-lg-3 col-sm-6 item" data-aos="fade-up">
                                <div class="card shadow-md mb-30">
                                    <div class="card_icon mb-20">
                                        <span
                                            class="card_number">{{ str_pad($loop->index + 1, 2, '0', STR_PAD_LEFT) }}</span>
                                        <i class="{{ $process->icon }}"></i>
                                    </div>
                                    <div class="card_content">
                                        <h4 class="card_title lc-2 mb-0">{{ $process->title }}</h4>
                                    </div>
                                    <!-- Card shape -->
                                    <span class="card_shape">
                                        <svg data-src="{{ asset('assets/front/theme3456/images/shape/work-shape-2.svg') }}"
                                            data-unique-ids="disabled" data-cache="disabled"></svg>
                                    </span>
                                </div>
                            </div>
                        @endforeach
                    @endif
                </div>
            </div>
        </section>
    @endif
    <!-- Works-area end -->

    <!-- About us start -->
    @if ($secInfo->about_section_status == 1)
        <section class="choose-area choose-area_v4 bg-dark">
            <div class="container-fluid ps-lg-0">
                <div class="row align-items-center gx-xl-5">

                    <div class="col-lg-6" data-aos="fade-up">
                        <div class="image">
                            <div class="img-1">
                                @if (!empty($aboutSectionImage))
                                    <img class="lazyload blur-up"
                                        src="{{ asset('assets/front/theme3456/images/placeholder.png') }}"
                                        data-src="{{ asset('assets/img/' . $aboutSectionImage) }}" alt="Image">
                                @endif
                            </div>
                            <div class="about-text">
                                <span
                                    class="h1 mb-0">{{ !empty($aboutSecInfo->subtitle) ? $aboutSecInfo->subtitle : '' }}</span>
                            </div>
                        </div>
                    </div>

                    <div class="col-lg-6" data-aos="fade-up">
                        <div class="content-title ptb-60 fluid-right">
                            <span class="subtitle subtitle_v3">
                                <span class="line"></span>
                                {{ !empty($aboutSecInfo->subtitle) ? $aboutSecInfo->subtitle : '' }}
                            </span>
                            <h2 class="title color-white mt-0 mb-0">
                                {{ !empty($aboutSecInfo->title) ? $aboutSecInfo->title : '' }}
                            </h2>
                            <div class="item-list pt-10">
                                <div class="card bg-none mt-20">
                                    <div class="card_content">
                                        <p class="card_text">{!! !empty($aboutSecInfo->text) ? nl2br($aboutSecInfo->text) : '' !!}</p>
                                    </div>
                                </div>
                            </div>
                            <div class="info-list pt-10">
                                @if ($secInfo->feature_section_status == 1)
                                    <div class="row align-items-center">
                                        @if (count($features) == 0)
                                            <div class="row text-center">
                                                <div class="col">
                                                    <h3 class="text-light">{{ __('No Feature Found') . '!' }}</h3>
                                                </div>
                                            </div>
                                        @else
                                            @foreach ($features as $feature)
                                                <div class="col-sm-6 col-xl-4">
                                                    <div class="card bg-none mt-20">
                                                        <div class="card_content p-25">
                                                            <div class="card_icon mb-10">
                                                                <i class="{{ $feature->icon }}"></i>
                                                            </div>
                                                            <p class="card_text">{{ $feature->title }}</p>
                                                        </div>
                                                    </div>
                                                </div>
                                            @endforeach
                                        @endif
                                    </div>
                                @endif
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
    @endif
    <!-- about us end -->

    <!-- Product-area start -->
    @if ($secInfo->featured_equipment_section_status == 1)
        <section class="product-area pt-100 pb-75">
            <div class="container">
                <div class="row">
                    <div class="col-12" data-aos="fade-up">
                        <div class="section-title title-inline mb-30">
                            <div>
                                <span class="subtitle subtitle_v3">
                                    <span class="line"></span>
                                    {{ !empty($equipmentSecInfo->featured_section_subtitle) ? $equipmentSecInfo->featured_section_subtitle : '' }}
                                </span>
                                <h2 class="title mw-100 mt-0">
                                    {{ !empty($equipmentSecInfo->featured_section_title) ? $equipmentSecInfo->featured_section_title : '' }}
                                </h2>
                            </div>
                            <a href="{{ route('all_equipment') }}" class="btn btn-lg btn-primary "
                                title="{{ __('View All') }}" target="_self">{{ __('View All') }}</a>
                        </div>
                    </div>
                    <div class="col-12" data-aos="fade-up">
                        <div class="swiper product-inline-slider" id="product-inline-slider-1">
                            @if (count($allEquipment) == 0)
                                <div class="row text-center">
                                    <div class="col">
                                        <h3>{{ __('No Equipment Found') . '!' }}</h3>
                                    </div>
                                </div>
                            @else
                                <div class="swiper-wrapper">
                                    @foreach ($allEquipment as $equipment)
                                        <div class="swiper-slide">
                                            <div class="product-default product-column border mb-25">
                                                <div class="row g-0 align-items-center">
                                                    <figure class="product_img col-xl-6">
                                                        <a href="{{ route('equipment_details', ['slug' => $equipment->slug]) }}"
                                                            target="_self" title="{{ __('Link') }}"
                                                            class="lazy-container ratio ratio-5-4">
                                                            <img class="lazyload"
                                                                src="{{ asset('assets/front/theme3456/images/placeholder.png') }}"
                                                                data-src="{{ asset('assets/img/equipments/thumbnail-images/' . $equipment->thumbnail_image) }}"
                                                                alt="Product">
                                                        </a>
                                                    </figure>
                                                    <div class="product_details col-xl-6 p-3">
                                                        <div class="product_title">
                                                            <span class="product_tag lh-1 font-xsm mb-1">
                                                                <a href="{{ route('equipment_details', ['slug' => $equipment->slug]) }}"
                                                                    target="_blank"
                                                                    title="{{ __('Link') }}">{{ $equipment->categoryName }}</a>
                                                            </span>
                                                            <h5 class="title lc-1 mb-0"><a
                                                                    href="{{ route('equipment_details', ['slug' => $equipment->slug]) }}"
                                                                    target="_self"
                                                                    title="{{ __('Link') }}">{{ strlen($equipment->title) > 25 ? mb_substr($equipment->title, 0, 25, 'UTF-8') . '...' : $equipment->title }}</a>
                                                            </h5>
                                                        </div>
                                                        <div class="product_price mt-15">
                                                            <div class="price">
                                                                @if (!empty($equipment->lowest_price))
                                                                    <span class="font-sm">{{ __('Starts From') }}</span>
                                                                    <div class="h5 mb-0 lh-1">
                                                                        @if (!empty($equipment->lowest_price))
                                                                            {{ $position == 'left' ? $symbol : '' }}{{ $equipment->lowest_price }}{{ $position == 'right' ? $symbol : '' }}
                                                                        @endif
                                                                    </div>
                                                                @endif
                                                            </div>
                                                        </div>
                                                        <div class="product_feature mt-15">
                                                            @php $features = explode(PHP_EOL, $equipment->features); @endphp
                                                            <ul class="product_feature_list list-unstyled icon-start toggle-list list-unstyled"
                                                                data-toggle-list="pricingToggle" data-toggle-show="2">
                                                                @foreach ($features as $key => $feature)
                                                                    <li class="lc-1 font-xsm"> <i
                                                                            class="far fa-check"></i> {{ $feature }}
                                                                    </li>
                                                                @endforeach
                                                            </ul>
                                                            <span class="show-more mt-1 font-xsm"
                                                                data-toggle-btn="toggleListBtn">
                                                                {{ __('Show More +') }}
                                                            </span>
                                                        </div>
                                                        <div class="product_bottom mt-15">
                                                            <a href="{{ route('equipment_details', ['slug' => $equipment->slug]) }}"
                                                                class="btn btn-md btn-primary"
                                                                title="{{ __('View') }}"
                                                                target="_self">{{ __('View') }}</a>
                                                            <div class="ratings flex-column align-items-start gap-2">
                                                                <div class="rate bg-img"
                                                                    data-bg-img="{{ asset('assets/front/theme3456/images/rate-star.png') }}">
                                                                    <div class="rating-icon bg-img"
                                                                        style="width: {{ $equipment->avgRating * 20 . '%;' }}"
                                                                        data-bg-img="{{ asset('assets/front/theme3456/images/rate-star.png') }}">
                                                                    </div>
                                                                </div>
                                                                <span
                                                                    class="ratings-total font-xsm">{{ number_format($equipment->avgRating, 2) }}
                                                                    ({{ $equipment->ratingCount . ' ' . __('rating') }})
                                                                </span>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div><!-- product-default -->
                                        </div>
                                    @endforeach
                            @endif
                        </div>
                        <div class="swiper-pagination position-static mt-15 mb-25"
                            id="product-inline-slider-1-pagination"></div>
                    </div>
                </div>
            </div>
            </div>
        </section>
    @endif
    <!-- Product-area end -->

    <!-- Counter-area start -->
    @if ($secInfo->counter_section_status == 1)
        <div class="counter-area counter-area_v4" data-aos="fade-up">
            <div class="counter-inner bg-img bg-cover pb-30"
                data-bg-img="{{ asset('assets/img/' . $counterSectionInfo->counter_section_image) }}">
                <div class="overlay"></div>
                <div class="container">
                    <div class="big-text d-none d-sm-flex">
                        <span class="h1 mb-0">{{ $counterSectionInfo->counter_section_title ?? '' }}</span>
                    </div>
                    @if ($secInfo->video_section_status == 1)
                        <div class="video-area ptb-60">
                            <a href="{{ $videoSection?->link }}"
                                class="video-btn video-btn-white youtube-popup rounded-0 mx-auto" title="Play Video">
                                <i class="fas fa-play"></i>
                            </a>
                        </div>
                    @endif
                    <div class="row justify">
                        @if (count($counters) == 0)
                            <div class="row text-center">
                                <div class="col">
                                    <h3>{{ __('No Information Found') . '!' }}</h3>
                                </div>
                            </div>
                        @else
                            @foreach ($counters as $counter)
                                <div class="col-lg col-sm-6">
                                    <div class="card text-center mb-30">
                                        <div class="card_icon color-primary mb-15">
                                            <i class="{{ $counter->icon }}"></i>
                                        </div>
                                        <div class="card_content">
                                            <h2 class="card_title color-white mb-10">
                                                <span class="counter">{{ $counter->amount }}</span>+
                                            </h2>
                                            <p class="card_text color-white lh-1">
                                                {{ $counter->title }}
                                            </p>
                                        </div>
                                    </div>
                                </div>
                            @endforeach
                        @endif
                    </div>
                </div>
            </div>
        </div>
    @endif
    <!-- Counter-area end -->

    <!-- equipment section area start -->
    @if ($secInfo->equipment_section_status == 1)
        <section class="product-area pt-100 pb-75">
            <div class="container">
                <div class="row">
                    <div class="col-12" data-aos="fade-up">
                        <div class="section-title title-center pb-30">
                            <span class="subtitle subtitle_v3">
                                <span class="line"></span>
                                {{ !empty($equipmentSecInfo->subtitle) ? $equipmentSecInfo->subtitle : '' }}
                                <span class="line"></span>
                            </span>
                            <h2 class="title mt-0 mb-30">
                                {{ !empty($equipmentSecInfo->title) ? $equipmentSecInfo->title : '' }}</h2>
                            <div class="tabs-navigation mb-20">
                                <ul class="nav nav-tabs" data-hover="fancyHover">
                                    <li class="nav-item active">
                                        <button class="nav-link hover-effect active btn-md rounded-0" data-bs-toggle="tab"
                                            data-bs-target="#tab1" type="button">{{ __('All') }}</button>
                                    </li>
                                    @foreach ($equipment_featured_Categories as $eq_cat)
                                        <li class="nav-item">
                                            <button class="nav-link hover-effect btn-md rounded-0" data-bs-toggle="tab"
                                                data-bs-target="#tab{{ $eq_cat->slug }}"
                                                type="button">{{ $eq_cat->name }}</button>
                                        </li>
                                    @endforeach
                                </ul>
                            </div>
                        </div>
                    </div>
                    <div class="col-12">
                        <div class="tab-content" data-aos="fade-up">

                            <div class="tab-pane slide show active" id="tab1">
                                <div class="row">
                                    @foreach (array_slice($cat_equipments, 0, 6) as $equipment)
                                        <div class="col-md-6">
                                            <div class="product-default product-column border mb-25">
                                                <div class="row g-0 align-items-center">
                                                    <figure class="product_img col-xl-6">
                                                        <a href="{{ route('equipment_details', ['slug' => $equipment->slug]) }}"
                                                            target="_self" title="{{ __('Link') }}"
                                                            class="lazy-container ratio ratio-5-4">
                                                            <img class="lazyload"
                                                                src="{{ asset('assets/front/theme3456/images/placeholder.png') }}"
                                                                data-src="{{ asset('assets/img/equipments/thumbnail-images/' . $equipment->equipment->thumbnail_image) }}"
                                                                alt="Product">
                                                        </a>
                                                    </figure>
                                                    <div class="product_details col-xl-6 p-3">
                                                        <div class="product_title">
                                                            <span class="product_tag lh-1 font-xsm mb-1">
                                                                <a href="{{ route('equipment_details', ['slug' => $equipment->slug]) }}"
                                                                    target="_blank"
                                                                    title="{{ __('Link') }}">{{ $equipment->category->name }}</a>
                                                            </span>
                                                            <h5 class="title lc-1 mb-0"><a
                                                                    href="{{ route('equipment_details', ['slug' => $equipment->slug]) }}"
                                                                    target="_self"
                                                                    title="{{ __('Link') }}">{{ strlen($equipment->title) > 25 ? mb_substr($equipment->title, 0, 25, 'UTF-8') . '...' : $equipment->title }}</a>
                                                            </h5>
                                                        </div>
                                                        <div class="pricing_option mt-10">
                                                            @if (!empty($equipment->equipment->per_day_price))
                                                                <span
                                                                    class="">{{ $position == 'left' ? $symbol : '' }}{{ $equipment->equipment->per_day_price }}{{ $position == 'right' ? $symbol : '' }}{{ '/' . __('Day') }}</span>
                                                            @endif
                                                            @if (!empty($equipment->equipment->per_week_price))
                                                                <span
                                                                    class="active">{{ $position == 'left' ? $symbol : '' }}{{ $equipment->equipment->per_week_price }}{{ $position == 'right' ? $symbol : '' }}{{ '/' . __('Week') }}</span>
                                                            @endif
                                                            @if (!empty($equipment->equipment->per_month_price))
                                                                <span
                                                                    class="">{{ $position == 'left' ? $symbol : '' }}{{ $equipment->equipment->per_month_price }}{{ $position == 'right' ? $symbol : '' }}{{ '/' . __('Month') }}</span>
                                                            @endif
                                                        </div>
                                                        <div class="product_feature mt-15">
                                                            @php $features = explode(PHP_EOL, $equipment->features); @endphp
                                                            <ul class="product_feature_list icon-start toggle-list list-unstyled"
                                                                data-toggle-list="pricingToggle" data-toggle-show="2">
                                                                @foreach ($features as $feature)
                                                                    <li class="font-xsm lc-1"><i
                                                                            class="far fa-check"></i>{{ $feature }}
                                                                    </li>
                                                                @endforeach
                                                            </ul>
                                                            <span class="show-more mt-1 font-xsm"
                                                                data-toggle-btn="toggleListBtn">
                                                                {{ __('Show More +') }}
                                                            </span>
                                                        </div>
                                                        <div class="product_bottom mt-15">
                                                            <a href="{{ route('equipment_details', ['slug' => $equipment->slug]) }}"
                                                                class="btn btn-md btn-primary"
                                                                title="{{ __('View') }}"
                                                                target="_self">{{ __('View') }}</a>
                                                            <div class="ratings flex-column align-items-start gap-2">
                                                                <div class="rate bg-img"
                                                                    data-bg-img="{{ asset('assets/front/theme3456/images/rate-star.png') }}">
                                                                    <div class="rating-icon bg-img"
                                                                        style="width: {{ $equipment->avgRating * 20 . '%;' }}"
                                                                        data-bg-img="{{ asset('assets/front/theme3456/images/rate-star.png') }}">
                                                                    </div>
                                                                </div>
                                                                <span
                                                                    class="ratings-total font-xsm">{{ number_format($equipment->avgRating, 2) }}
                                                                    ({{ $equipment->ratingCount . ' ' . __('rating') }})
                                                                </span>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                            <!-- product-default -->
                                        </div>
                                    @endforeach
                                </div>
                                <div class="text-center mt-15 mb-25" data-aos="fade-up">
                                    <a href="{{ route('all_equipment') }}" class="btn btn-lg btn-primary"
                                        title="{{ __('View All') }}" target="_self">{{ __('View All') }}</a>
                                </div>
                            </div>
                            @foreach ($equipment_featured_Categories as $eq_cat)
                                <div class="tab-pane slide" id="tab{{ $eq_cat->slug }}">
                                    <div class="row">
                                        @foreach ($eq_cat->equipmentContent as $equipment)
                                            <div class="col-md-6">
                                                <div class="product-default product-column border mb-25">
                                                    <div class="row g-0 align-items-center">
                                                        <figure class="product_img col-xl-6">
                                                            <a href="{{ route('equipment_details', ['slug' => $equipment->slug]) }}"
                                                                target="_self" title="{{ __('Link') }}"
                                                                class="lazy-container ratio ratio-5-4">
                                                                <img class="lazyload"
                                                                    src="{{ asset('assets/front/theme3456/images/placeholder.png') }}"
                                                                    data-src="{{ asset('assets/img/equipments/thumbnail-images/' . $equipment->equipment->thumbnail_image) }}"
                                                                    alt="Product">
                                                            </a>
                                                        </figure>
                                                        <div class="product_details col-xl-6 p-3">
                                                            <div class="product_title">
                                                                <span class="product_tag lh-1 font-xsm mb-1">
                                                                    <a href="#" target="_blank"
                                                                        title="{{ __('Link') }}">{{ $equipment->category->name }}</a>
                                                                </span>
                                                                <h5 class="title lc-1 mb-0"><a href="#"
                                                                        target="_self"
                                                                        title="{{ __('Link') }}">{{ strlen($equipment->title) > 25 ? mb_substr($equipment->title, 0, 25, 'UTF-8') . '...' : $equipment->title }}</a>
                                                                </h5>
                                                            </div>
                                                            <div class="pricing_option mt-10">
                                                                @if (!empty($equipment->equipment->per_day_price))
                                                                    <span
                                                                        class="">{{ $position == 'left' ? $symbol : '' }}{{ $equipment->equipment->per_day_price }}{{ $position == 'right' ? $symbol : '' }}{{ '/' . __('Day') }}</span>
                                                                @endif
                                                                @if (!empty($equipment->equipment->per_week_price))
                                                                    <span
                                                                        class="active">{{ $position == 'left' ? $symbol : '' }}{{ $equipment->equipment->per_week_price }}{{ $position == 'right' ? $symbol : '' }}{{ '/' . __('Week') }}</span>
                                                                @endif
                                                                @if (!empty($equipment->equipment->per_month_price))
                                                                    <span
                                                                        class="">{{ $position == 'left' ? $symbol : '' }}{{ $equipment->equipment->per_month_price }}{{ $position == 'right' ? $symbol : '' }}{{ '/' . __('Month') }}</span>
                                                                @endif
                                                            </div>
                                                            <div class="product_feature mt-15">
                                                                @php $features = explode(PHP_EOL, $equipment->features); @endphp
                                                                <ul class="product_feature_list icon-start toggle-list list-unstyled"
                                                                    data-toggle-list="pricingToggle" data-toggle-show="2">
                                                                    @foreach ($features as $feature)
                                                                        <li class="font-xsm lc-1"><i
                                                                                class="far fa-check"></i>{{ $feature }}
                                                                        </li>
                                                                    @endforeach
                                                                </ul>
                                                                <span class="show-more mt-1 font-xsm"
                                                                    data-toggle-btn="toggleListBtn">
                                                                    {{ __('Show More +') }}
                                                                </span>
                                                            </div>
                                                            <div class="product_bottom mt-15">
                                                                <a href="{{ route('equipment_details', ['slug' => $equipment->slug]) }}"
                                                                    class="btn btn-md btn-primary"
                                                                    title="{{ __('View') }}"
                                                                    target="_self">{{ __('View') }}</a>
                                                                <div class="ratings flex-column align-items-start gap-2">
                                                                    <div class="rate bg-img"
                                                                        data-bg-img="{{ asset('assets/front/theme3456/images/rate-star.png') }}">
                                                                        <div class="rating-icon bg-img"
                                                                            data-bg-img="{{ asset('assets/front/theme3456/images/rate-star.png') }}">
                                                                        </div>
                                                                    </div>
                                                                    <span
                                                                        class="ratings-total font-xsm">{{ number_format($equipment->avgRating, 2) }}
                                                                        ({{ $equipment->ratingCount . ' ' . __('rating') }})
                                                                    </span>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div><!-- product-default -->
                                            </div>
                                        @endforeach
                                    </div>
                                    <div class="text-center mt-15 mb-25" data-aos="fade-up">
                                        <a href="{{ route('all_equipment') . '?category=' . $eq_cat->slug }}"
                                            class="btn btn-lg btn-primary" title="{{ __('View All') }}"
                                            target="_self">{{ __('View All') }}</a>
                                    </div>
                                </div>
                            @endforeach
                        </div>
                    </div>
                </div>
            </div>
        </section>
    @endif
    <!-- Product-area end -->

    <!-- Testimonial-area start -->
    @if ($secInfo->testimonial_section_status == 1)
        <section class="testimonial-area testimonial-area_v5 pb-100" data-aos="fade-up">
            <div class="container">
                <div class="section-title title-center mb-50">
                    <span class="subtitle subtitle_v3">
                        <span class="line"></span>
                        {{ !empty($testimonialSecInfo->subtitle) ? $testimonialSecInfo->subtitle : '' }}
                        <span class="line"></span>
                    </span>
                    <h2 class="title mt-0">{{ !empty($testimonialSecInfo->title) ? $testimonialSecInfo->title : '' }}
                    </h2>
                </div>
                <div class="swiper" id="testimonial-slider-3">
                    @if (count($testimonials) == 0)
                        <div class="row text-center">
                            <div class="col">
                                <h3>{{ __('No Testimonial Found') . '!' }}</h3>
                            </div>
                        </div>
                    @else
                        <div class="swiper-wrapper">
                            @foreach ($testimonials as $testimonial)
                                <div class="swiper-slide">
                                    <div class="slider-item">
                                        <div class="client mb-25">
                                            <div class="client-info d-flex align-items-center">
                                                <div class="client-img">
                                                    <div class="lazy-container ratio ratio-1-1">
                                                        @if (is_null($testimonial->image))
                                                            <img class="lazyload"
                                                                src="{{ asset('assets/front/theme3456/images/placeholder.png') }}"
                                                                data-src="{{ asset('assets/img/profile.jpg') }}"
                                                                alt="Person Image">
                                                        @else
                                                            <img class="lazyload"
                                                                src="{{ asset('assets/front/theme3456/images/placeholder.png') }}"
                                                                data-src="{{ asset('assets/img/clients/' . $testimonial->image) }}"
                                                                alt="Person Image">
                                                        @endif
                                                    </div>
                                                </div>
                                                <div class="content">
                                                    <h6 class="name">{{ $testimonial->name }}</h6>
                                                    <span class="designation">{{ $testimonial->occupation }}</span>
                                                </div>
                                            </div>
                                            <span class="icon"><i class="fal fa-quote-right"></i></span>
                                        </div>
                                        <div class="quote">
                                            <p class="text mb-0">{{ $testimonial->comment }} </p>
                                        </div>
                                    </div>
                                </div>
                            @endforeach
                        </div>
                    @endif
                    <div class="swiper-pagination position-static mt-20" id="testimonial-slider-3-pagination"></div>
                </div>
            </div>
            <div class="images d-none d-lg-block">
                <div class="img img-1">
                    <img class="lazyload" src="{{ asset('assets/front/theme3456/images/placeholder.png') }}"
                        @if (!empty($testimonialSecInfo->testimonial_section_image)) data-src="{{ asset('assets/img/' . $testimonialSecInfo->testimonial_section_image) }}" @endif
                        alt="Image">
                </div>
                <div class="img img-2">
                    <img class="lazyload" src="{{ asset('assets/front/theme3456/images/placeholder.png') }}"
                        @if (!empty($testimonialSecInfo->testimonial_section_image_2)) data-src="{{ asset('assets/img/' . $testimonialSecInfo->testimonial_section_image_2) }}" @endif
                        alt="Image">
                </div>
            </div>
        </section>
    @endif
    <!-- Testimonial-area end -->

    <!-- Blog-area start -->
    @if ($secInfo->blog_section_status == 1)
        <section class="blog-area blog-area_v5 pt-100 pb-70" data-aos="fade-up">
            <div class="overlay bg-img bg-cover"
                @if (empty($blogSecInfo->blog_section_image)) data-bg-img="{{ asset('assets/front/theme3456/images/blog-bg-2.jpg') }}" @else data-bg-img="{{ asset('assets/img/blog-images/' . $blogSecInfo->blog_section_image) }}" @endif>
            </div>
            <div class="container">
                <div class="section-title title-inline mb-50">
                    <div>
                        <span class="subtitle subtitle_v3 color-light">
                            <span class="line"></span>
                            {{ !empty($blogSecInfo->subtitle) ? $blogSecInfo->subtitle : '' }}
                            <span class="line"></span>
                        </span>
                        <h2 class="title mt-0 color-white">
                            {{ !empty($blogSecInfo->title) ? $blogSecInfo->title : '' }}
                        </h2>
                    </div>
                    <a href="{{ route('blog') }}" class="btn btn-lg btn-primary" title="{{ __('View All') }}"
                        target="_self">{{ __('View All') }}</a>
                </div>
                <div class="row">
                    @foreach ($blogs as $blog)
                        <div class="col-md-6 col-xl-4">
                            <article class="card border p-10 mb-30">
                                <div class="card_img">
                                    <a href="{{ route('blog_details', ['slug' => $blog->slug]) }}" target="_self"
                                        title="{{ __('Details') }}" class="lazy-container ratio ratio-2-3">
                                        <img class="lazyload"
                                            src="{{ asset('assets/front/theme3456/images/placeholder.png') }}"
                                            data-src="{{ asset('assets/img/blogs/' . $blog->image) }}" alt="Blog Image">
                                    </a>
                                </div>
                                <div class="card_content p-25">
                                    <ul class="card_list list-unstyled mb-15">
                                        <li class="icon-start">
                                            <a href="{{ route('blog') }}" target="_self"
                                                title="{{ __('Link') }}"><i
                                                    class="fal fa-user"></i>{{ $blog->author }}</a>
                                        </li>
                                        <li class="icon-start">
                                            <a href="{{ route('blog') }}" target="_self"
                                                title="{{ __('Link') }}"><i
                                                    class="fal fa-calendar-check"></i>{{ date_format($blog->created_at, 'M d, Y') }}</a>
                                        </li>
                                        <li class="icon-start">
                                            <a href="{{ route('blog') }}" target="_self"
                                                title="{{ __('Link') }}"><i
                                                    class="fal fa-tag"></i>{{ $blog->categoryName }}</a>
                                        </li>
                                    </ul>
                                    <h4 class="card_title lc-1 mb-0 color-white">
                                        <a href="{{ route('blog_details', ['slug' => $blog->slug]) }}" target="_self"
                                            title="{{ __('Link') }}">
                                            {{ strlen($blog->title) > 30 ? mb_substr($blog->title, 0, 30, 'UTF-8') . '...' : $blog->title }}
                                        </a>
                                    </h4>
                                    <div class="cta-btn mt-15">
                                        <a href="{{ route('blog_details', ['slug' => $blog->slug]) }}"
                                            class="btn-text color-primary" target="_self"
                                            title="{{ __('READ MORE') }}">{{ __('READ MORE') }}</a>
                                    </div>
                                </div>
                            </article>
                        </div>
                    @endforeach
                </div>
            </div>
        </section>
    @endif
    <!-- Blog-area end -->
@endsection
@section('script')
    <script type="text/javascript" src="{{ asset('assets/js/equipment.js') }}"></script>

    <script type="text/javascript" src="{{ asset('assets/js/product.js') }}"></script>
@endsection
