<!DOCTYPE html>
<html lang="{{ $currentLanguageInfo->code }}" @if ($currentLanguageInfo->direction == 1) dir="rtl" @endif>

<head>
    {{-- required meta tags --}}
    <meta charset="utf-8">
    <meta http-equiv="x-ua-compatible" content="ie=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
    {{-- <link rel="apple-touch-icon" href="{{ asset('assets/img/' . $websiteInfo->favicon) }}"> --}}
    <link rel="shortcut icon" type="image/png" href="{{ asset('assets/img/' . $websiteInfo->favicon) }}">
    {{-- csrf-token for ajax request --}}
 <meta name="csrf-token" content="{{ csrf_token() }}">

    {{-- title --}}
    <title>@yield('pageHeading') {{ '| ' . $websiteInfo->website_title }}</title>

    <meta name="keywords" content="@yield('metaKeywords')">
    <meta name="description" content="@yield('metaDescription')">
    <meta name="theme-color" content="{{ $basicInfo->primary_color }}" />

    {{-- include styles --}}
    @php
        $primaryColor = $basicInfo->primary_color;
        $secondaryColor = $basicInfo->secondary_color;
        $breadcrumbOverlayColor = $basicInfo->breadcrumb_overlay_color;
    @endphp


    @if ($basicInfo->theme_version == 1 || $basicInfo->theme_version == 2)
        {{-- fav icon --}}
        @includeIf('frontend.partials.styles')
        {{-- fav icon --}}
    @elseif(
        $basicInfo->theme_version == 3 ||
            $basicInfo->theme_version == 4 ||
            $basicInfo->theme_version == 5 ||
            $basicInfo->theme_version == 6)
        @if (request()->routeIs('index'))
            @includeIf('frontend.partials.theme3456_styles')
        @else
            @includeIf('frontend.partials.styles')
        @endif

        {{-- {{ asset('assets/front/theme3456/images/logo/fav.png')}} --}}


        <style>
            :root {
                --color-primary: #{{ $primaryColor }};
                --color-secondary: #{{ $secondaryColor }};
            }
        </style>
    @else
    @endif
    <link rel="manifest" crossorigin="use-credentials" href="{{ asset('manifest.json') }}" />

    {{-- additional style --}}
    @yield('style')
    <style>
        .whatsapp-btn {
            z-index: 3;
        }
    </style>
</head>

<body class="@if ($basicInfo->theme_version == 4) theme-dark @endif
  @if (!request()->routeIs('index') && ($basicInfo->theme_version == 3 ||
          $basicInfo->theme_version == 4 ||
          $basicInfo->theme_version == 5)) breadcrumbs-area_v2_active @endif">

    {{-- preloader start --}}
    <div class="preloader">
        <div class="lds-ellipsis">
            <span></span>
            <span></span>
            <span></span>
        </div>
    </div>
    {{-- preloader end --}}

    @if (
        $basicInfo->theme_version == 3 ||
            $basicInfo->theme_version == 4 ||
            $basicInfo->theme_version == 5 ||
            $basicInfo->theme_version == 6)
        <div class="cart-wrapper">
            <a href="{{ route('shop.cart') }}" class="btn-icon">
                <i class="fal fa-shopping-bag"></i>
                <span id="product-count">{{ count($cartItemInfo) }} {{ __('Items') }}</span>
            </a>
        </div>
    @endif

    {{-- header start --}}
    @if ($basicInfo->theme_version == 1)
        <header class="header-area-one">
            {{-- include header-top --}}
            @includeIf('frontend.partials.header.header-top-v1')
            {{-- include header-nav --}}
            @includeIf('frontend.partials.header.header-nav-v1')
        </header>
    @elseif($basicInfo->theme_version == 2)
        <header class="header-area-two">
            {{-- include header-top --}}
            @includeIf('frontend.partials.header.header-top-v2')
            {{-- include header-nav --}}
            @includeIf('frontend.partials.header.header-nav-v2')
        </header>
    @elseif($basicInfo->theme_version == 3)
        @includeIf('frontend.partials.header.header-nav-v3')
    @elseif($basicInfo->theme_version == 4)
        @includeIf('frontend.partials.header.header-nav-v4')
    @elseif($basicInfo->theme_version == 5)
        @includeIf('frontend.partials.header.header-nav-v5')
    @elseif($basicInfo->theme_version == 6)
        @includeIf('frontend.partials.header.header-nav-v6')
    @endif
    {{-- header end --}}

    @yield('content')

    {{-- back to top start --}}
    @if ($basicInfo->theme_version == 1 || $basicInfo->theme_version == 2)
        <a href="#" class="back-to-top"><i class="fas fa-angle-up"></i></a>
    @else
        <div class="go-top"><i class="fal fa-angle-up"></i></div>
    @endif
    {{-- back to top end --}}

    {{-- floating whatsapp button --}}
    @if ($basicInfo->whatsapp_status == 1 && $basicInfo->tawkto_status == 0)
        <div class="whatsapp-btn"></div>
    @endif
    {{-- tawk.to button --}}
    @if ($basicInfo->whatsapp_status == 0 && $basicInfo->tawkto_status == 1)
        @php
            $directLink = str_replace('tawk.to', 'embed.tawk.to', $basicInfo->tawkto_direct_chat_link);
            $directLink = str_replace('chat/', '', $directLink);
        @endphp
        <!--Start of Tawk.to Script-->
        <script type="text/javascript">
            "use strict";
            var Tawk_API = Tawk_API || {},
                Tawk_LoadStart = new Date();
            (function() {
                var s1 = document.createElement("script"),
                    s0 = document.getElementsByTagName("script")[0];
                s1.async = true;
                s1.src = '{{ $directLink }}';
                s1.charset = 'UTF-8';
                s1.setAttribute('crossorigin', '*');
                s0.parentNode.insertBefore(s1, s0);
            })();
        </script>
        <!--End of Tawk.to Script-->
    @endif

    {{-- announcement popup --}}
    @includeIf('frontend.partials.popups')

    {{-- cookie alert --}}
    @if (!is_null($cookieAlertInfo) && $cookieAlertInfo->cookie_alert_status == 1)
        @include('cookie-consent::index')
    @endif


    {{-- include footer --}}

    @includeIf('frontend.partials.footer.footer-v' . $basicInfo->theme_version)

    @if ($basicInfo->theme_version == 1 || $basicInfo->theme_version == 2)
        @includeIf('frontend.partials.scripts')
    @elseif(
        $basicInfo->theme_version == 3 ||
            $basicInfo->theme_version == 4 ||
            $basicInfo->theme_version == 5 ||
            $basicInfo->theme_version == 6)
        @if (request()->routeIs('index'))
            @includeIf('frontend.partials.theme3456_scripts')
        @else
            @includeIf('frontend.partials.scripts')
        @endif
    @else
    @endif
    {{-- include scripts --}}

    {{-- additional script --}}
    @yield('script')
</body>

</html>
